@@ -4,7 +4,7 @@ use experimental qw( signatures );
 use stable qw( postderef );
 use true;
 
-package Data::Section::Writer 0.04 {
+package Data::Section::Writer 0.05 {
 
   # ABSTRACT: Write __DATA__ section files for Data::Section, Data::Section::Simple or Mojo::Loader::data_section
 
@@ -14,6 +14,7 @@ package Data::Section::Writer 0.04 {
   use Class::Tiny qw( perl_filename _files _same _formats );
   use Ref::Util qw( is_coderef is_blessed_ref is_plain_arrayref );
   use MIME::Base64 qw(encode_base64);
+  use File::Temp ();
 
   sub BUILD ($self, $) {
 
@@ -104,8 +105,19 @@ package Data::Section::Writer 0.04 {
       $self->_same(0);
     }
 
-    # re-write the perl with the
-    $self->perl_filename->spew_utf8($perl);
+    if(-f $self->perl_filename) {
+      use autodie qw( truncate close );
+      # re-write the perl to the file, using the existing inode
+      my $backup = Path::Tiny->new(File::Temp::tempnam($self->perl_filename->parent, $self->perl_filename->basename));
+      $self->perl_filename->copy($backup) if -f $self->perl_filename;
+      my $fh = $self->perl_filename->openrw_utf8;
+      truncate $fh, 0;
+      print $fh $perl or die "unable to write to @{[ $self->perl_filename ]} $!";
+      close $fh;
+      $backup->remove if -f $backup;
+    } else {
+      $self->perl_filename->spew_utf8($perl);
+    }
 
     return $self;
   }
@@ -179,7 +191,7 @@ Data::Section::Writer - Write __DATA__ section files for Data::Section, Data::Se
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
